# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from uuid import UUID
from authentik_client.models.user_group import UserGroup
from typing import Optional, Set
from typing_extensions import Self

class MicrosoftEntraProviderGroup(BaseModel):
    """
    MicrosoftEntraProviderGroup Serializer
    """ # noqa: E501
    id: UUID
    microsoft_id: StrictStr
    group: UUID
    group_obj: UserGroup
    provider: StrictInt
    attributes: Dict[str, Any]
    __properties: ClassVar[List[str]] = ["id", "microsoft_id", "group", "group_obj", "provider", "attributes"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MicrosoftEntraProviderGroup from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "group_obj",
            "attributes",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of group_obj
        if self.group_obj:
            _dict['group_obj'] = self.group_obj.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MicrosoftEntraProviderGroup from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "microsoft_id": obj.get("microsoft_id"),
            "group": obj.get("group"),
            "group_obj": UserGroup.from_dict(obj["group_obj"]) if obj.get("group_obj") is not None else None,
            "provider": obj.get("provider"),
            "attributes": obj.get("attributes")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.rbac_api import RbacApi


class TestRbacApi(unittest.TestCase):
    """RbacApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RbacApi()

    def tearDown(self) -> None:
        pass

    def test_rbac_initial_permissions_create(self) -> None:
        """Test case for rbac_initial_permissions_create

        """
        pass

    def test_rbac_initial_permissions_destroy(self) -> None:
        """Test case for rbac_initial_permissions_destroy

        """
        pass

    def test_rbac_initial_permissions_list(self) -> None:
        """Test case for rbac_initial_permissions_list

        """
        pass

    def test_rbac_initial_permissions_partial_update(self) -> None:
        """Test case for rbac_initial_permissions_partial_update

        """
        pass

    def test_rbac_initial_permissions_retrieve(self) -> None:
        """Test case for rbac_initial_permissions_retrieve

        """
        pass

    def test_rbac_initial_permissions_update(self) -> None:
        """Test case for rbac_initial_permissions_update

        """
        pass

    def test_rbac_initial_permissions_used_by_list(self) -> None:
        """Test case for rbac_initial_permissions_used_by_list

        """
        pass

    def test_rbac_permissions_assigned_by_roles_assign(self) -> None:
        """Test case for rbac_permissions_assigned_by_roles_assign

        """
        pass

    def test_rbac_permissions_assigned_by_roles_list(self) -> None:
        """Test case for rbac_permissions_assigned_by_roles_list

        """
        pass

    def test_rbac_permissions_assigned_by_roles_unassign_partial_update(self) -> None:
        """Test case for rbac_permissions_assigned_by_roles_unassign_partial_update

        """
        pass

    def test_rbac_permissions_assigned_by_users_assign(self) -> None:
        """Test case for rbac_permissions_assigned_by_users_assign

        """
        pass

    def test_rbac_permissions_assigned_by_users_list(self) -> None:
        """Test case for rbac_permissions_assigned_by_users_list

        """
        pass

    def test_rbac_permissions_assigned_by_users_unassign_partial_update(self) -> None:
        """Test case for rbac_permissions_assigned_by_users_unassign_partial_update

        """
        pass

    def test_rbac_permissions_list(self) -> None:
        """Test case for rbac_permissions_list

        """
        pass

    def test_rbac_permissions_retrieve(self) -> None:
        """Test case for rbac_permissions_retrieve

        """
        pass

    def test_rbac_permissions_roles_destroy(self) -> None:
        """Test case for rbac_permissions_roles_destroy

        """
        pass

    def test_rbac_permissions_roles_list(self) -> None:
        """Test case for rbac_permissions_roles_list

        """
        pass

    def test_rbac_permissions_roles_partial_update(self) -> None:
        """Test case for rbac_permissions_roles_partial_update

        """
        pass

    def test_rbac_permissions_roles_retrieve(self) -> None:
        """Test case for rbac_permissions_roles_retrieve

        """
        pass

    def test_rbac_permissions_roles_update(self) -> None:
        """Test case for rbac_permissions_roles_update

        """
        pass

    def test_rbac_permissions_users_destroy(self) -> None:
        """Test case for rbac_permissions_users_destroy

        """
        pass

    def test_rbac_permissions_users_list(self) -> None:
        """Test case for rbac_permissions_users_list

        """
        pass

    def test_rbac_permissions_users_partial_update(self) -> None:
        """Test case for rbac_permissions_users_partial_update

        """
        pass

    def test_rbac_permissions_users_retrieve(self) -> None:
        """Test case for rbac_permissions_users_retrieve

        """
        pass

    def test_rbac_permissions_users_update(self) -> None:
        """Test case for rbac_permissions_users_update

        """
        pass

    def test_rbac_roles_create(self) -> None:
        """Test case for rbac_roles_create

        """
        pass

    def test_rbac_roles_destroy(self) -> None:
        """Test case for rbac_roles_destroy

        """
        pass

    def test_rbac_roles_list(self) -> None:
        """Test case for rbac_roles_list

        """
        pass

    def test_rbac_roles_partial_update(self) -> None:
        """Test case for rbac_roles_partial_update

        """
        pass

    def test_rbac_roles_retrieve(self) -> None:
        """Test case for rbac_roles_retrieve

        """
        pass

    def test_rbac_roles_update(self) -> None:
        """Test case for rbac_roles_update

        """
        pass

    def test_rbac_roles_used_by_list(self) -> None:
        """Test case for rbac_roles_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
